Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // GroupVersion is group version used to register these objects GroupVersion = schema.GroupVersion{Group: "katalog.fybrik.io", Version: "v1alpha1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type Asset ¶
type Asset struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// +required
Spec AssetSpec `json:"spec"`
}
+kubebuilder:object:root=true +kubebuilder:resource:scope=Namespaced Asset defines an asset in the catalog
func (*Asset) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Asset.
func (*Asset) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Asset) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type AssetList ¶
type AssetList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Asset `json:"items"`
}
+kubebuilder:object:root=true AssetList contains a list of Asset resources
func (*AssetList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AssetList.
func (*AssetList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*AssetList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type AssetSpec ¶
type AssetSpec struct {
// Asset details
Details datacatalog.ResourceDetails `json:"details"`
// Asset metadata
Metadata datacatalog.ResourceMetadata `json:"metadata"`
// Reference to a Secret resource holding credentials for this asset
SecretRef SecretRef `json:"secretRef"`
}
func (*AssetSpec) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AssetSpec.
func (*AssetSpec) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SecretRef ¶
type SecretRef struct {
// Name of the Secret resource
Name string `json:"name"`
// Namespace of the Secret resource. If it is empty then the asset namespace is used.
Namespace string `json:"namespace,omitempty"`
}
SecretRef is a reference to a local Kubernetes secret.
func (*SecretRef) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SecretRef.
func (*SecretRef) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.